#import "BuzzBoosterPlugin.h"
#import "FLCampaignFloatingActionButtonFactory+View.h"
#import "FLCampaignEntryViewFactory+View.h"

@implementation BuzzBoosterPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"buzz_booster"
            binaryMessenger:[registrar messenger]];
  BuzzBoosterPlugin* instance = [[BuzzBoosterPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];

  FLCampaignFloatingActionButtonFactory* campaignFloatingActionButtonFactory =
      [[FLCampaignFloatingActionButtonFactory alloc] initWithMessenger:registrar.messenger];
  [registrar registerViewFactory:campaignFloatingActionButtonFactory withId:@"CampaignFloatingActionButton"];
  FLCampaignEntryViewFactory* campaignEntryViewFactory =
      [[FLCampaignEntryViewFactory alloc] initWithMessenger:registrar.messenger];
  [registrar registerViewFactory:campaignEntryViewFactory withId:@"CampaignEntryView"];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"init" isEqualToString:call.method]) {
    NSString *appKey = call.arguments[@"appKey"];
    if (appKey != nil && ![appKey isKindOfClass:[NSNull class]]) {
      BSTConfig *config = [BSTConfig configWithBlock:^(BSTConfigBuilder * _Nonnull builder) {
        builder.appKey = appKey;
      }];
      [BuzzBooster initializeWithConfig:config];
      result(nil);
    } else {
      FlutterError *error = [FlutterError errorWithCode:@"400" message:@"AppKey is required" details:nil];
      result(error);
    }
  } else if ([@"setUserId" isEqualToString:call.method]) {
    NSString *userId = call.arguments[@"userId"];
    [BuzzBooster setUserId:userId];
    result(nil);
  } else if ([@"sendEvent" isEqualToString:call.method]){
    NSString *eventName = call.arguments[@"eventName"];
    NSDictionary * _Nullable eventValues = call.arguments[@"eventValues"];
    if (eventValues != nil && ![eventValues isKindOfClass:[NSNull class]]) {
      [BuzzBooster sendEventWithEventName:eventName
                              eventValues:eventValues];
    } else {
      [BuzzBooster sendEventWithEventName:eventName];
    }
    result(nil);
  } else if ([@"showInAppMessage" isEqualToString:call.method]){
    UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    [BuzzBooster showInAppMessageWithRootViewController:viewController];
    result(nil);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end
