import 'package:flutter_test/flutter_test.dart';
import 'package:buzz_booster/buzz_booster.dart';
import 'package:buzz_booster/buzz_booster_platform_interface.dart';
import 'package:buzz_booster/buzz_booster_method_channel.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockBuzzBoosterPlatform 
    with MockPlatformInterfaceMixin
    implements BuzzBoosterPlatform {

  @override
  Future<void> setUserId(String? userId) => Future.value();

  @override
  Future<void> init(String appKey) => Future.value();

  @override
  Future<void> sendEvent(String eventName, Map<String, String>? eventValues) => Future.value();

  @override
  Future<void> showInAppMessage() => Future.value();
}

void main() {
  final BuzzBoosterPlatform initialPlatform = BuzzBoosterPlatform.instance;

  test('$MethodChannelBuzzBooster is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelBuzzBooster>());
  });

  test('setUserId', () async {
    BuzzBooster buzzBoosterPlugin = BuzzBooster();
    MockBuzzBoosterPlatform fakePlatform = MockBuzzBoosterPlatform();
    BuzzBoosterPlatform.instance = fakePlatform;
  
    await buzzBoosterPlugin.setUserId("Damon");
  });

  test('init', () async {
    BuzzBooster buzzBoosterPlugin = BuzzBooster();
    MockBuzzBoosterPlatform fakePlatform = MockBuzzBoosterPlatform();
    BuzzBoosterPlatform.instance = fakePlatform;
  
    await buzzBoosterPlugin.init("appKey");
  });

  test('sendEvent', () async {
    BuzzBooster buzzBoosterPlugin = BuzzBooster();
    MockBuzzBoosterPlatform fakePlatform = MockBuzzBoosterPlatform();
    BuzzBoosterPlatform.instance = fakePlatform;
  
    await buzzBoosterPlugin.sendEvent("eventName", {
      "eventValuesKey1":"eventValuesValue1"
    });
  });

  test('sendEventWithNoValues', () async {
    BuzzBooster buzzBoosterPlugin = BuzzBooster();
    MockBuzzBoosterPlatform fakePlatform = MockBuzzBoosterPlatform();
    BuzzBoosterPlatform.instance = fakePlatform;
  
    await buzzBoosterPlugin.sendEvent("eventName", null);
  });

  test('showInAppMessage', () async {
    BuzzBooster buzzBoosterPlugin = BuzzBooster();
    MockBuzzBoosterPlatform fakePlatform = MockBuzzBoosterPlatform();
    BuzzBoosterPlatform.instance = fakePlatform;
  
    await buzzBoosterPlugin.showInAppMessage();
  });
}
